[gtk+] Only a GtkMisc widget should be passed to gtk_tool_button_new()



commit b8ec73a52fe3dc3012db78f45bfcafa2cb3e14ae
Author: Javier Jardón <jjardon gnome org>
Date:   Mon Apr 26 20:05:51 2010 +0200

    Only a GtkMisc widget should be passed to gtk_tool_button_new()
    
    Reported by Hernando Torque here:
    https://bugzilla.gnome.org/show_bug.cgi?id=616851

 gtk/gtktoolbutton.c |    4 +++-
 1 files changed, 3 insertions(+), 1 deletions(-)
---
diff --git a/gtk/gtktoolbutton.c b/gtk/gtktoolbutton.c
index a0e16b9..e8a6eca 100644
--- a/gtk/gtktoolbutton.c
+++ b/gtk/gtktoolbutton.c
@@ -928,7 +928,7 @@ gtk_tool_button_new_from_stock (const gchar *stock_id)
 /**
  * gtk_tool_button_new:
  * @label: (allow-none): a string that will be used as label, or %NULL
  * @icon_widget: (allow-none): a widget that will be used as icon widget, or %NULL
  *
  * Creates a new %GtkToolButton using @icon_widget as icon and @label as
  * label.
@@ -943,6 +943,8 @@ gtk_tool_button_new (GtkWidget	 *icon_widget,
 {
   GtkToolButton *button;
 
+  g_return_val_if_fail (GTK_IS_MISC (icon_widget), NULL);
+
   button = g_object_new (GTK_TYPE_TOOL_BUTTON,
                          "label", label,
                          "icon-widget", icon_widget,
@@ -928,7 +928,7 @@ gtk_tool_button_new_from_stock (const gchar *stock_id)
  * gtk_tool_button_new:
  * @label: (allow-none): a string that will be used as label, or %NULL
- * @icon_widget: (allow-none): a widget that will be used as icon widget, or %NULL
+ * @icon_widget: (allow-none): a #GtkMisc widget that will be used as icon widget, or %NULL
  *
  * Creates a new %GtkToolButton using @icon_widget as icon and @label as



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]